@@ -105,13 +105,13 @@ batchTemplates = {'slurm' : {'engine'     : _slurmEngineBatchTemplate,
                   }
 
 class Master(object):
-    idleEngines = set()
 
     def __init__(self, args):
         self.args = args
         self.db = getDatabase(checkInit=False)
         self.client = None
         self.finished = False
+        self.idleEngines = set()
 
         projectName = args.projectName
 
@@ -172,7 +172,7 @@ class Master(object):
         for eid, qs in iteritems(qstatus):
             for key, count in iteritems(qs):
                 if count < 0 or count > 100:
-                    _logger.debug("qstatus['%s'] = %s", key, count)
+                    _logger.debug("Engine id %s qstatus['%s'] = %s", eid, key, count)
                 totals[key] += count
 
         return totals
@@ -184,7 +184,23 @@ class Master(object):
             # some tasks are not yet assigned to engines => not idle
             return
 
-        engineCount = len(qstatus)
+        # TBD: iterate over client.ids instead?
+        # From http://python.6.x6.nabble.com/IPython-User-IPython-parallel-shutdown-unused-engines-td5053278.html#a5053309
+        # # get queue status
+        # qs = rc.queue_status()
+        #
+        # # identify idle engines
+        # idle = []
+        # for eid in rc.ids:
+        #     if qs[eid]['queue'] + qs[eid]['tasks'] == 0:
+        #         idle.append(eid)
+        #
+        # # shut them down
+        # dv = rc.direct_view(idle)
+        # dv.shutdown()
+
+
+        engineCount = len(qstatus) # TBD: any different/better to use len(self.client.ids)?
         if engineCount == 0:
             _logger.info("No engines are running")
             return
@@ -203,6 +219,11 @@ class Master(object):
 
                 try:
                     self.client.shutdown(targets=list(newlyIdle), block=False)
+
+                    # TBD?
+                    # dv = self.client.direct_view(list(newlyIdle))
+                    # dv.shutdown(block=False)
+
                 except Exception as e:
                     _logger.debug("shutdownIdleEngines: %s", e)
                     # ignore the error
@@ -553,6 +574,11 @@ class Master(object):
 
         asyncResults = []
 
+        # TBD: Use "self.client[:]" for a direct view rather than load-balanced view
+        # TBD: This should pack nodes rather than spreading the load, which makes it easier
+        # TBD: to shutdown idle nodes, rather than having nodes running only a single task.
+        # view = None if runLocal else self.client[:]
+
         view = None if runLocal else self.client.load_balanced_view() # retries=2)
 
         db = getDatabase()
