@@ -260,14 +260,18 @@ def _addRegionMap(regionMap, rewriteList):
         levelElt.append(rewrite)
 
 def _addRewrites(levelElt, rewriteSet):
+    from semver import VersionInfo
 
     def _appendRewrite(From, to):
         'Helper function to reduce redundancy'
         node = ET.Element('rewrite', attrib={'from': From, 'to': to})
         levelElt.append(node)
 
-    byAEZ = rewriteSet.byAEZ
-    byBasin = rewriteSet.byBasin
+    version = parse_version_info()
+
+    gcam5 = (version > VersionInfo(5, 0, 0))
+    byBasin = gcam5 and rewriteSet.byBasin
+    byAEZ   = not gcam5 and rewriteSet.byAEZ
 
     for rewrite in rewriteSet.rewrites:
         From = rewrite.From             # "from" is a keyword, thus "From"
@@ -826,17 +830,17 @@ def runBatchQuery(scenario, queryName, queryPath, outputDir, xmldb='',
     delete = not noDelete
 
     # Look for both the literal name as given as well as the name with "-" and "_" replaced with " "
-    filename = _findOrCreateQueryFile(basename, queryPath, regions, regionMap=regionMap,
-                                      rewriteSetList=rewriters, rewriteParser=rewriteParser,
-                                      delete=delete)
-    if not filename:
+    queryFile = _findOrCreateQueryFile(basename, queryPath, regions, regionMap=regionMap,
+                                       rewriteSetList=rewriters, rewriteParser=rewriteParser,
+                                       delete=delete)
+    if not queryFile:
         raise PygcamException("runBatchQuery: file for query '%s' was not found." % basename)
 
     if not csvFile:
         csvFile = "%s-%s.csv" % (saveAs or mainPart, scenario)    # compute default filename
         csvFile = csvFile.replace(' ', '_')                       # eliminate spaces for convenience
 
-    csvPath = runModelInterface(scenario, filename, outputDir, csvFile, xmldb=xmldb,
+    csvPath = runModelInterface(scenario, outputDir, csvFile, queryFile=queryFile, xmldb=xmldb,
                                 miLogFile=miLogFile, noDelete=noDelete, noRun=noRun)
     return csvPath
 
